export const taxonomy_event_public = [
    {
        label: "Petit enfant",
        value: "i8gf49541q",
    },
    {
        label: "Petit enfant » 1 an",
        value: "tdtpdh546x",
    },
    {
        label: "Petit enfant » 2 ans",
        value: "19hb3u884v",
    },
    {
        label: "Petit enfant » 3 ans",
        value: "cl7oi9xaig",
    },
    {
        label: "Enfant",
        value: "omg40jn2yl",
    },
    {
        label: "Enfant » 4 ans",
        value: "a04ryxt74a",
    },
    {
        label: "Enfant » 5 ans",
        value: "2u0ugvi72u",
    },
    {
        label: "Enfant » 6 ans",
        value: "8btkbsp9ei",
    },
    {
        label: "Enfant » 7 ans",
        value: "gp881gyhmy",
    },
    {
        label: "Enfant » 8 ans",
        value: "me9vnw7vnk",
    },
    {
        label: "Enfant » 9 ans",
        value: "11ps76le1h",
    },
    {
        label: "Enfant » 10 ans",
        value: "rf2m1fbrot",
    },
    {
        label: "Enfant » 11 ans",
        value: "79qhii8mnf",
    },
    {
        label: "Adolescent",
        value: "ah0rbc2qr4",
    },
    {
        label: "Adolescent » 12 ans",
        value: "x6rmmxao6i",
    },
    {
        label: "Adolescent » 13 ans",
        value: "1pn83a9xkw",
    },
    {
        label: "Adolescent » 14 ans",
        value: "b8skpvhfka",
    },
    {
        label: "Adolescent » 15 ans",
        value: "snvxin8j4j",
    },
    {
        label: "Adolescent » 16 ans",
        value: "v4ty7v0hab",
    },
    {
        label: "Adolescent » 17 ans",
        value: "1x1ii6jxhu",
    },
    {
        label: "Adulte",
        value: "5lfbjyeea0",
    },
    {
        label: "Plus de 60 ans",
        value: "58cuuquwed",
    },
    {
        label: "Tout public",
        value: "ry275hefdy",
    },
];
