(()=>{"use strict";jQuery(document).ready((function(e){e("#contentview-preview a").click((function(o){e(".hide-in-preview, #section-byline, #global_statusmessage").toggle("fast"),o.preventDefault()})),e("#formfield-form-widgets-svg_icon input").click((function(o){var s=e(this);e(this).attr("checked")?(e(this).prop("checked",!1),e(this).removeAttr("checked"),e(this).css("box-shadow","none"),e(this).css("border-color","#DEE2ED")):e("#formfield-form-widgets-svg_icon input").each((function(o,t){s[0]===t?(e(this).prop("checked",!0),e(this).attr("checked","checked"),e(this).css("border-color","#007a99"),e(this).css("box-shadow","0 0 0 0.25rem rgb(0 122 153 / 25%)")):(e(this).prop("checked",!1),e(this).removeAttr("checked"),e(this).css("box-shadow","none"),e(this).css("border-color","#DEE2ED"))}))}));var o=e("li:has(a[href*='@@stats'])");e("#collapse-personaltools li:eq(0)").after(o)})),jQuery(window).on("load",(function(e){var o=$("#plone-authentic-sources-menu").wrap("<ul class='plonetoolbar-authentic-sources-menu'>").parent();$(".personaltools-wrapper").prepend(o);var s=$("#plone-smartweb-help-menu").wrap("<ul class='plonetoolbar-smartweb-help-menu'>").parent();$(".personaltools-wrapper").prepend(s)}))})();