document.addEventListener("DOMContentLoaded",(function(){$(".swiper").each((function(e){var i=parseInt($(this).attr("data-nb-results-by-batch"));isNaN(i)&&(i=1),new Swiper($(this)[0],{slidesPerView:1,slidesPerGroup:1,spaceBetween:10,pagination:{el:".swiper-pagination",clickable:!0},navigation:{nextEl:".swiper-button-next",prevEl:".swiper-button-prev"},breakpoints:{320:{slidesPerView:1,slidesPerGroup:1},576:{slidesPerView:i>1?2:1,slidesPerGroup:i>1?2:1},768:{slidesPerView:i>2?2:i,slidesPerGroup:i>2?2:i},992:{slidesPerView:i>2?3:i,slidesPerGroup:i>2?3:i},1200:{slidesPerView:i,slidesPerGroup:i}}})}))}));