html,
body {
  max-width: 100%;
  overflow-x: initial !important;
}

.row {
  padding: 0;
  margin: 0;
}

.breadcrumb {
  padding: 0;
}

// FOR SCROLL

body .outer-wrapper {
  &>.container {
    max-width: 100% !important;
    padding: 0 !important;

  }
}

.r-annuaire-wrapper {
  @media screen and (min-width:1200px) {
    max-width: 100%;
    margin-right: inherit;
    padding-right: 0;
    padding-left: 0;
  }
}

#portal-column-content {
  padding: 0 !important;
}



#portal-column-content {
  h1 {
    font-size: 0px;
    position: absolute;
  }
}

header#content-header {
  position: sticky;
  top: 0;
  background: #fff;
}

#viewlet-below-content-title,
#viewlet-below-content-description {
  display: none;
}

article>header {
  margin-bottom: 0px;
}

.r-annuaire-result {
  grid-area: 1 / 1 / 3 / 2;
}

.r-map.annuaire-map {
  position: sticky;
  grid-area: 1 / 2 / 2 / 3;
}


/////////

.r-wrapper {
  display: block;

  @media screen and (min-width:1200px) {
    display: grid;
    grid-template-columns: minmax(20px, 800px) minmax(20px, 100%);
    justify-content: space-between;
    width: calc(558px + 50vw);
    margin-left: auto;
    gap: 40px;
  }

  @media screen and (min-width:1400px) {
    width: calc(648px + 50vw);
  }

  .r-result {
    padding-bottom: 2rem;

    &-list {
      padding: 0;

      .r-list-item-group {
        position: relative;
        list-style: none;
        margin: 1rem 0;

        .r-list-item-link {
          inset: 0px !important;
          position: absolute !important;
        }

        .r-list-item {
          display: flex;
          height: 100%;
          flex-direction: column;

          @media screen and (min-width:600px) {
            flex-direction: row;
          }

          .r-item-img {
            width: 100%;
            padding-bottom: 56%;
            position: relative;
            z-index: -1;
            background-color: #000;

            &.r-item-img-placeholder {
              background: #f2f2f2;
            }

            @media screen and (min-width:600px) {
              width: 246px;
              height: 149px;
              padding-bottom: 0;
              flex: 246px 0 0;
            }

            background-size: cover;
            border-radius: 5px;

            div,
            img {
              border-radius: 5px;
            }
          }

          .r-item-text {
            margin-top: 0.6rem;

            @media screen and (min-width:600px) {
              margin-left: 1.5rem;
              margin-top: 0;
            }

            flex-grow: 1;

            a {
              position: relative;
            }

            .r-item-title {
              font-weight: bold;
              display: block;
            }

            .r-item-categorie {
              display: block;
            }

            .r-item-all {
              display: flex;
              gap: 10px;

              .r-item-adresse {
                width: 36%;
              }

              .phones {
                display: flex;
                gap: 0 5px;
                flex-wrap: wrap;
              }

              .mails {
                display: flex;
                flex-direction: column;
              }
            }
          }
        }
      }
    }
  }
}

// content
.r-content-description {
  border-bottom: solid 1px #e6e6e6;
}

.contactTextAll {
  margin-top: 1rem;
  position: relative;

  @media screen and (min-width:700px) {
    padding-right: 128px;
  }

  .annuaire-logo {
    margin-top: .5rem;
    max-width: 128px;

    @media screen and (min-width:700px) {
      position: absolute;
      top: 0;
      right: 0;
    }
  }
}

.annuaire-info-title {
  font-weight: bold;
}

.annuaire-website-link,
.annaire-adresse,
.annuaire-phone,
.annuaire-website-mails,
.annuaire-social-link,
.annuaire-schedul {
  display: flex;
  gap: 10px;
  align-items: first baseline;
  margin-bottom: .5rem;

  a {
    text-decoration: none;
  }
}

.annuaire-phone,
.annuaire-website-mails {
  span {
    display: block;
    font-weight: 500;

    a {
      font-weight: 400;
    }
  }
}

.annuaire-website-mails {

  div {

    span {
      display: block;
    }
  }
}


.annuaire-social-link {
  margin: .5rem 0;

  ul {
    display: flex;
    gap: 10px;
    margin: 0;

    li {
      list-style: none;
    }
  }
}

.annuaire-website-link {

  // display: flex;
  // gap: 10px;
  // position: relative;
  // overflow: hidden;
  // margin: .5rem 0;
  ul {

    // display: flex;
    // flex-direction: row;
    // flex-wrap: wrap;
    // margin-left: -.5em;
    // margin-bottom: 0;
    li {
      // padding: 0 .5em;
      // text-align: center;
      // border-left: 1.5px solid #000;
      // background-color: #fff;
      list-style: none;
      // line-height: 0.8;
      // margin: .3rem 0;
    }
  }
}

.annuaire-day-close {
  color: #e61d1d;
}

.annuaire-day-open {
  color: rgba(129, 201, 149, 1.0);
}

.annuaire-schedul {
  li {
    list-style: none;
  }
}

// FOR BLA

.r-wrapper {

  .r-result {
    &-list {
      .r-list-item-group {
        .r-list-item {
          .r-item-img {}

          .r-item-text {
            font-size: 13px;

            &:after {
              content: "";
              width: 50px;
              height: 50px;
              background: yellow;
              border-radius: 50px;
            }

            .r-item-title {
              font-size: 18px;
            }

            .r-item-categorie {
              margin-bottom: 5px;
            }

            .r-item-all {
              color: #727272;

              a {
                color: #000;
              }

              .r-item-adresse {
                .itineraty {
                  margin-top: 5px;

                  &:before {
                    content: "";
                    width: 15px;
                    height: 15px;
                    display: inline-block;
                    background-size: contain;
                    background: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 7.68 10.97'%3E%3Cg id='Calque_2' data-name='Calque 2'%3E%3Cg id='Calque_1-2' data-name='Calque 1'%3E%3Cpath id='map-marker' d='M3.84,5.21A1.37,1.37,0,1,1,5.21,3.84h0A1.37,1.37,0,0,1,3.84,5.21M3.84,0A3.84,3.84,0,0,0,0,3.84H0C0,6.72,3.84,11,3.84,11S7.68,6.72,7.68,3.84A3.84,3.84,0,0,0,3.84,0Z'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E") no-repeat;
                    vertical-align: middle;
                  }
                }
              }

              .r-item-contact {
                width: 100%;
                .topics {
                  margin-top: 10px;
                  span {
                    padding: 5px;
                    background: #f1f1f1;
                    border-radius: 5px;
                    margin-right: 5px;
                    
                  }
                }
              }
            }
          }
        }
      }
    }
  }

}

.r-load-more {
  margin-bottom: 2rem;
  text-align: center;

  button {
    background: #000;
    border: solid 1px transparent;
    color: #fff;
    padding: 0.4rem 1rem;
    border-radius: 10px;
    border-bottom-left-radius: 10px;
    border-bottom-left-radius: 0px;
    font-weight: bold;
    font-size: 14px;
    margin: 0 auto;
    display: block;

    &:hover {
      background: rgba(0, 0, 0, 0.871);
    }
  }
}

.r-map {
  @media screen and (max-width:1200px) {
    margin-top: 2rem !important;
  }

  .leaflet-container {
    @media screen and (max-width:1200px) {
      height: 50vh !important;
    }
  }
}



// //  No Map
//   // Main
.no-map {
  @media screen and (min-width: 600px) {
    .r-annuaire-wrapper {
      display: block;
    }

    .r-wrapper {
      .r-result-list {
        max-width: 1296px;
        display: grid;
        grid-template-columns: repeat(auto-fill, minmax(244px, 1fr));
        gap: 20px;
      }

      .r-list-item-group {
        display: block !important;
        transition: all .2s ease;

        &:hover,
        &:focus {
          transform: translateY(-10px) !important;
        }

        .r-list-item {
          flex-direction: column !important;
          box-shadow: 0 8px 26px rgba(0, 0, 0, 0.08);

          .r-item-img {
            flex: inherit;
            width: 100% !important;
            aspect-ratio: 5 / 3;
            margin-bottom: 0;
            height: auto;
          }

          .r-item-text {
            display: block;
            margin-right: 1.5rem;
            margin-bottom: .5rem;
            margin-top: .5rem;

            &:after {
              display: none;
            }

            .r-item-categorie {
              margin-bottom: .25rem;
              margin-top: .25rem;
            }

            .r-item-title {
              margin-bottom: .25rem;
              margin-top: .25rem;
              font-size: 16px;
            }

            .r-item-all {
              display: block !important;

              .r-item-adresse {
                margin-bottom: .25rem;
                margin-top: .25rem;
                width: auto;
              }

              .phones {}

              .mails,
              .phones,
              .topics {
                margin-bottom: .25rem;
                margin-top: .25rem;
              }
            }
          }
        }
      }
    }
  }
}

// content

.no-map {
  .r-result.r-annuaire-result {
    max-width: 1296px;
  }

  .annuaire-content {
    max-width: 700px;
    margin: 0 auto;
  }
}