.schedul-Filter {
    width: 100%;

    @media screen and (min-width:630px) {
        width: auto;
    }
}

.period-filter {
    width: 100%;

    @media screen and (min-width:630px) {
        width: auto;
    }

    .period-filter-toggler {
        width: 100%;

        @media screen and (min-width:630px) {
            width: auto;
        }

        &>button {
            display: flex;
            justify-content: center;
            align-items: center;
            min-width: 150px;
            background: transparent;
            color: hsl(0, 0%, 20%);
            box-sizing: border-box;
            font-weight: bold;
            font-size: 14px;
            letter-spacing: 1.4px;
            text-align: left;
            min-height: 30px;
            outline: 0 !important;
            position: relative;
            -webkit-transition: all 100ms;
            transition: all 100ms;
            background-color: white;
            border-color: none;
            border-radius: 0;
            border-width: 1px;
            border: solid 1px #fff;
            box-sizing: border-box;
            height: 40px;
            border-radius: 10px;
            width: 100%;

            @media screen and (min-width:630px) {
                width: auto;
            }

            @media screen and (max-width:629px) {
                background-color: transparent;
                border-color: hsl(0, 0%, 70%);
                color: hsl(0, 0%, 20%);
                border: solid 1px #CFCFCF;
            }

            &:hover {
                background-color: transparent;
                border-color: hsl(0, 0%, 70%);
                color: hsl(0, 0%, 20%);
                border: solid 1px #CFCFCF;
            }

            &:focus,
            &:active {
                border-color: #2684FF !important;
                background: transparent !important;
                color: hsl(0, 0%, 20%) !important;
                box-shadow: 0 0 0 2px #2684FF !important;
            }

            &:after {
                content: "";
                background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' height='20' width='20' viewBox='0 0 20 20' aria-hidden='true' focusable='false' fill='%23CFCFCF' class='css-tj5bde-Svg'%3E%3Cpath d='M4.516 7.548c0.436-0.446 1.043-0.481 1.576 0l3.908 3.747 3.908-3.747c0.533-0.481 1.141-0.446 1.574 0 0.436 0.445 0.408 1.197 0 1.615-0.406 0.418-4.695 4.502-4.695 4.502-0.217 0.223-0.502 0.335-0.787 0.335s-0.57-0.112-0.789-0.335c0 0-4.287-4.084-4.695-4.502s-0.436-1.17 0-1.615z'%3E%3C/path%3E%3C/svg%3E");
                display: inline-block;
                width: 20px;
                height: 20px;
                background-repeat: no-repeat;
                border: inherit;
                border-color: transparent;
                background-position: center;
                vertical-align: bottom;
                margin-left: auto;
            }
        }
    }

}

.perdiod-filter-range {
    padding: 5px 16px;

    input {
        border: solid 1px hsl(0, 0%, 42%) !important;
        border-radius: 5px;
        padding: 5px 9px;
        color: hsl(0, 0%, 20%);
        border: solid 1px hsl(0, 0%, 70%) !important;
    }
}