.userrole-authenticated .r-search-container{padding:0 20px 0 123px}.r-search-container{margin:0 auto;max-width:1330px;padding:0 20px}.r-search-container .full-width{left:50%;margin-left:-50vw;margin-right:-50vw;position:relative;right:50%;width:100vw}.r-search-container .r-search-highlighter{background:#0000;border-bottom:2px solid #f9b300;font-weight:700;padding:0;position:relative}.r-search-container .r-search-header{border-bottom:1px solid #000}.r-search-container .r-search-header-title{font-size:15px;font-weight:700;text-transform:uppercase}.r-search-container .r-search-header-count{color:gray;font-size:10px;text-transform:uppercase}.r-search-container .r-search-result{display:grid;gap:1.5rem;grid-template-columns:repeat(auto-fit,minmax(250px,1fr));margin-top:2rem}.r-search-container .r-search.search-bar-filter,.r-search-container .r-search.search-bar-filter form{position:relative}.r-search-container .r-search.search-bar-filter input,.r-search-container .r-search.search-bar-filter label{width:100%}.r-search-container .r-search.search-bar-filter input{border:1px solid #ccc;color:#000;font-weight:700;height:50px;letter-spacing:1.2px;line-height:50px;padding:0 10px}.r-search-container .r-search.search-bar-filter input::placeholder{color:#000;font-size:12px;letter-spacing:1.2px;opacity:1;text-transform:uppercase}.r-search-container .r-search.search-bar-filter button{background:url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3E%3Cg data-name='Calque 2'%3E%3Cpath d='M11.08 6.77a4.31 4.31 0 1 0-4.31 4.31 4.32 4.32 0 0 0 4.31-4.31m4.92 8A1.24 1.24 0 0 1 14.77 16a1.17 1.17 0 0 1-.86-.37l-3.3-3.28a6.77 6.77 0 1 1 1.74-1.74l3.3 3.3a1.25 1.25 0 0 1 .35.86' data-name='Calque 1' style='fill:%23141414;fill-rule:evenodd'/%3E%3C/g%3E%3C/svg%3E") no-repeat;background-position:50%;background-size:80%;border:none;bottom:0;position:absolute;right:10px;top:0;width:20px}.r-search-container .r-search-select{border-radius:0;height:50px}.r-search-container .r-search-list{margin-top:20px;overflow-y:scroll}@media screen and (min-width:992px){.r-search-container .r-search-list{max-height:375px}}.r-search-container .r-search-list .r-search-item{border-bottom:1px solid #00000040;display:flex;font-size:14px;gap:10px;list-style:none;padding:1rem 0}.r-search-container .r-search-list .r-search-item .r-search-img{background-repeat:no-repeat;background-size:cover;flex-basis:100%;flex-basis:91px;flex-grow:0;flex-shrink:0;height:61px;width:91px}.offcanvas-header .btn-close{position:absolute;right:10px;top:10px}.search-contact .r-search-img,.search-events .r-search-img,.search-news .r-search-img{float:left;margin-right:.5rem}.r-search-result mark{display:initial}