#contentview-preview .icon-preview:before {
  content: '\e833';
}

.pat-sortable> :hover {
  cursor: move;
}

.pat-sortable {
  position: relative;
  display: block;

  .sortable-section {
    padding: 0.5rem;
    margin-top: 1rem;
    margin-bottom: 1rem;
    border: 1px solid #dee2e6 !important;
  }
}

.hidden-section-title {
  opacity: 0.3;
}

.section-title {
  display: inline-block;
  vertical-align: middle;
}

.content-section {
  h2 {
    display: inline-block;
  }
}

.show-hide-banner {
  display: inline-block;
  padding: 15px;
  background: #fff;
  border: solid 1px #e6e6e6;
}

.header-section {
  background: #f2f2f2;
  padding: 0 1rem;
  line-height: 1.9;
  margin-top: 1rem !important;
  margin-bottom: 1rem !important;
}

table.table_schedule {
  cursor: default;
}

ul.plonetoolbar-authentic-sources-menu {
  padding-inline-start: 0;
  width: 100%;
}

ul.plonetoolbar-smartweb-help-menu {
  padding-inline-start: 0;
  width: 100%;
}

a.manage[class*="contenttype-imio-smartweb-"] {
    &:before {
        display: none;
    }
    svg {
      margin-right: 5px;
    }
}

// layout select

.manage-section .form_section_size option {
  font-size: 15px;    
}
.manage-section .form_section_size option:before {
  content:"";
  display: block;
  width: 40px;
  aspect-ratio: 16/9;
}
.form_section_size .icon_col-sm-3:before {
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 170 100'%3E%3Cpath d='M5 5h40v90H5z' style='fill:%2388c6ef;stroke-width:0'/%3E%3Cpath d='M45 5v90H5V5h40m5-5H0v100h50V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3Cpath d='M45 5h40v90H45z' style='fill:%23fff;stroke-width:0'/%3E%3Cpath d='M85 5v90H45V5h40m5-5H40v100h50V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3Cpath d='M85 5h40v90H85z' style='fill:%23fff;stroke-width:0'/%3E%3Cpath d='M125 5v90H85V5h40m5-5H80v100h50V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3Cpath d='M125 5h40v90h-40z' style='fill:%23fff;stroke-width:0'/%3E%3Cpath d='M165 5v90h-40V5h40m5-5h-50v100h50V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3C/svg%3E");
  background-size: contain;
  background-repeat: no-repeat;
}
.form_section_size .icon_col-sm-4:before {
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 170 100'%3E%3Cpath d='M5 5h53.36v90H5z' style='fill:%2388c6ef;stroke-width:0'/%3E%3Cpath d='M58.36 5v90H5V5h53.36m5-5H0v100h63.36V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3Cpath d='M58.27 5h53.36v90H58.27z' style='fill:%23fff;stroke-width:0'/%3E%3Cpath d='M111.64 5v90H58.28V5h53.36m5-5H53.28v100h63.36V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3Cpath d='M111.64 5H165v90h-53.36z' style='fill:%23fff;stroke-width:0'/%3E%3Cpath d='M165 5v90h-53.36V5H165m5-5h-63.36v100H170V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3C/svg%3E");
  background-size: contain;
  background-repeat: no-repeat;
}
.form_section_size .icon_col-sm-6:before {
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 170 100'%3E%3Cpath d='M5 5h160v90H5z' style='fill:%23fff;stroke-width:0'/%3E%3Cpath d='M165 5v90H5V5h160m5-5H0v100h170V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3Cpath d='M5 5h80v90H5z' style='fill:%2388c6ef;stroke-width:0'/%3E%3Cpath d='M85 5v90H5V5h80m5-5H0v100h90V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3C/svg%3E");
  background-size: contain;
  background-repeat: no-repeat;
}
.form_section_size .icon_col-sm-8:before {
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 170 100'%3E%3Cpath d='M5 5h53.36v90H5z' style='fill:%2388c6ef;stroke-width:0'/%3E%3Cpath d='M58.36 5v90H5V5h53.36m5-5H0v100h63.36V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3Cpath d='M58.27 5h53.36v90H58.27z' style='fill:%2388c6ef;stroke-width:0'/%3E%3Cpath d='M111.64 5v90H58.28V5h53.36m5-5H53.28v100h63.36V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3Cpath d='M111.64 5H165v90h-53.36z' style='fill:%23fff;stroke-width:0'/%3E%3Cpath d='M165 5v90h-53.36V5H165m5-5h-63.36v100H170V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3C/svg%3E");
  background-size: contain;
  background-repeat: no-repeat;
}
.form_section_size .icon_col-sm-9:before {
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 170 100'%3E%3Cpath d='M5 5h40v90H5z' style='fill:%2388c6ef;stroke-width:0'/%3E%3Cpath d='M45 5v90H5V5h40m5-5H0v100h50V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3Cpath d='M45 5h40v90H45z' style='fill:%2388c6ef;stroke-width:0'/%3E%3Cpath d='M85 5v90H45V5h40m5-5H40v100h50V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3Cpath d='M85 5h40v90H85z' style='fill:%2388c6ef;stroke-width:0'/%3E%3Cpath d='M125 5v90H85V5h40m5-5H80v100h50V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3Cpath d='M125 5h40v90h-40z' style='fill:%23fff;stroke-width:0'/%3E%3Cpath d='M165 5v90h-40V5h40m5-5h-50v100h50V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3C/svg%3E");
  background-size: contain;
  background-repeat: no-repeat;
}
.form_section_size .icon_col-sm-12:before {
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 170 100'%3E%3Cpath d='M5 5h160v90H5z' style='fill:%2388c6ef;stroke-width:0'/%3E%3Cpath d='M165 5v90H5V5h160m5-5H0v100h170V0Z' style='fill:%230081f4;stroke-width:0'/%3E%3C/svg%3E");
  background-size: contain;
  background-repeat: no-repeat;
}